@@ -121,6 +121,8 @@ def show_events_filter(response):
 
 # Filter for the show_sets function
 def show_sets_filter(response):
+    if 'data' not in response:
+        return
     if response['data']['event'] is None:
         return
 
@@ -212,7 +214,10 @@ def show_sets_filter(response):
                 cur_player = {}
                 cur_player['playerId'] = user['player']['id']
                 cur_player['playerTag'] = user['player']['gamerTag']
-                cur_player['entrantId'] = user['entrants'][0]['id']
+                if user['entrants'] is not None:
+                    cur_player['entrantId'] = user['entrants'][0]['id']
+                else:
+                    cur_player['entrantId'] = node['slots'][j]['entrant']['id']
                 players.append(cur_player)
             
             cur_set['entrant' + str(j+1) + 'Players'] = players
